Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(342)

Unified Diff: Source/bindings/v8/custom/V8BlobCustomHelpers.h

Issue 74213009: File constructor understands lastModified. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/bindings/v8/custom/V8BlobCustomHelpers.h
diff --git a/Source/bindings/v8/custom/V8BlobCustomHelpers.h b/Source/bindings/v8/custom/V8BlobCustomHelpers.h
index 8bb22f0dac3b41646943a1244aba78b405b509df..1b29815aabf43cd5eeec7a1c83b2dab958a0a2c3 100644
--- a/Source/bindings/v8/custom/V8BlobCustomHelpers.h
+++ b/Source/bindings/v8/custom/V8BlobCustomHelpers.h
@@ -40,12 +40,32 @@ class BlobBuilder;
// Shared code between the custom constructor bindings for Blob and File.
namespace V8BlobCustomHelpers {
+// Parsed properties from a BlobPropertyBag or a FilePropertyBag.
+struct ParsedProperties {
+ String contentType;
+ String endings;
+
+ // False if this contains the properties of a BlobPropertyBag.
+ bool hasFileProperties;
+
+private:
+ double m_lastModifiedDate;
+ bool m_hasLastModifiedDate;
+
+
+public:
+ void setLastModifiedDate(double);
+ double lastModifiedDate();
+
+ ParsedProperties(bool hasFileProperties);
+};
+
// Extracts the "type" and "endings" properties out of the BlobPropertyBag passed to a Blob constructor.
// http://www.w3.org/TR/FileAPI/#constructorParams
// Returns true if everything went well, false if a JS exception was thrown.
-bool processBlobPropertyBag(v8::Local<v8::Value> propertyBag, const char* blobClassName, String& contentType, String& endings, v8::Isolate*);
+bool processBlobPropertyBag(v8::Local<v8::Value> propertyBag, const char* blobClassName, ParsedProperties&, v8::Isolate*);
-// Appends the blobParts passed to a Blob constructor into a BlobBuilder.
+// Appends the blobParts passed to a Blob or File constructor into a BlobBuilder.
// http://www.w3.org/TR/FileAPI/#constructorParams
// Returns true if everything went well, false if a JS exception was thrown.
bool processBlobParts(v8::Local<v8::Object> blobParts, uint32_t blobPartsLength, const String& endings, BlobBuilder&, v8::Isolate*);

Powered by Google App Engine
This is Rietveld 408576698